Merge
authorsspitsyn
Tue, 17 Oct 2017 21:50:22 +0000
changeset 47642 aeb80739a5ca
parent 47641 5fbb4e3b5c92 (diff)
parent 47637 87141990dde5 (current diff)
child 47643 51a922ce7c4a
Merge
make/corba/Makefile
--- a/test/hotspot/jtreg/serviceability/jvmti/ModuleAwareAgents/ClassFileLoadHook/libMAAClassFileLoadHook.c	Tue Oct 17 18:54:03 2017 +0200
+++ b/test/hotspot/jtreg/serviceability/jvmti/ModuleAwareAgents/ClassFileLoadHook/libMAAClassFileLoadHook.c	Tue Oct 17 21:50:22 2017 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2016, 2017, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -137,6 +137,7 @@
     jvmtiEventCallbacks callbacks;
     jvmtiError err;
 
+    printf("agent options: %s\n", options);
     if (options != NULL) {
         if (strstr(options, "with_early_vmstart") != NULL) {
             with_early_vm_start_capability = JNI_TRUE;
@@ -205,9 +206,9 @@
     }
 
     /*
      * Expecting that we always get ClassFileLoadHook events in the VM Start phase.
      */
-    if (cflh_events_vm_start_count == 0) {
+    if (with_early_vm_start_capability == JNI_TRUE && cflh_events_vm_start_count == 0) {
         throw_exc(env, "Didn't get ClassFileLoadHook events in start phase!\n");
         return FAILED;
     }
@@ -205,9 +206,9 @@
 
     /*
-     * Expecting that we always get ClassFileLoadHook events in the VM Start phase.
+     * Expecting ClassFileLoadHook events in the VM Start phase if early_vm_start is enabled.
      */